@@ -90,7 +90,7 @@ class OriOptimizeEnv(gym.Env):
         self._agent_orientation = self.initial_ori  # 重置环境其实就是将模型的角度摆正，摆回原来的位置
         self.env.getInitialOri(self.initial_ori[0], self.initial_ori[1], self.initial_ori[2])
         self.current_support_volume = self.env.runCompute()
-        observation = self._get_obs()
+        _, observation = self._get_obs()
         info = self._get_info()
         print("reset success")
         # if self.render_mode == "human":
@@ -111,11 +111,13 @@ class OriOptimizeEnv(gym.Env):
         terminated = np.array_equal(self._agent_orientation, self._target_orientation)  # 是否结束
         reward += -0.05 if not terminated else 0  # 如果结束获得奖励，未结束的时候获得的奖励不能为0，应该为负，避免模型停在原地不动
 
-        _, observation = self._get_obs()
-        _, info = self._get_info()
+        observation = self._get_obs()
+        obs = observation.items()
+        information = self._get_info()
+        info = information.items()
         print("step forward")
 
-        return observation, reward, terminated, False, info
+        return obs, reward, terminated, False, info
 
     def render(self, mode="human"):
         """对目前来说这个函数没有作用"""
